@@ -7,11 +7,10 @@
 #ifndef CUTTLEFISHCOLORSCHEMES_H
 #define CUTTLEFISHCOLORSCHEMES_H
 
+#include <QAbstractItemModel>
 #include <QObject>
 #include <QString>
 
-class QAbstractItemModel;
-
 class KColorSchemeManager;
 
 namespace CuttleFish
